@@ -51,13 +51,18 @@ hergm.wrapper <- function(seed, hergm_list)
     as.double(hergm_list$eta_precision_rate),
     as.double(hergm_list$eta),
     as.integer(hergm_list$indicator),
-    as.integer(hergm_list$Clist$heads), as.integer(hergm_list$Clist$tails),
-    as.integer(hergm_list$Clist$nedges), as.integer(hergm_list$MCMCparams$MCMC.init.maxedges), as.integer(hergm_list$Clist$n),
-    as.integer(hergm_list$Clist$dir), as.integer(hergm_list$Clist$bipartite),
+    as.integer(hergm_list$Clist$heads), 
+    as.integer(hergm_list$Clist$tails),
+    as.integer(hergm_list$Clist$nedges), 
+    as.integer(hergm_list$MCMCparams$MCMC.init.maxedges), 
+    as.integer(hergm_list$Clist$n),
+    as.integer(hergm_list$Clist$dir), 
+    as.integer(hergm_list$Clist$bipartite),
     as.integer(hergm_list$Clist$nterms), 
     as.character(hergm_list$Clist$fnamestring), 
     as.character(hergm_list$Clist$snamestring),
-    as.character(hergm_list$MHproposal$name), as.character(hergm_list$MHproposal$pkgname),
+    as.character(hergm_list$MHproposal$name), 
+    as.character(hergm_list$MHproposal$pkgname),
     as.double(hergm_list$Clist$inputs),
     as.double(hergm_list$Clist$inputs),
     as.double(hergm_list$theta),
@@ -65,10 +70,14 @@ hergm.wrapper <- function(seed, hergm_list)
     sample = as.double(t(hergm_list$MCMCparams$stats)),
     as.integer(hergm_list$MCMCparams$burnin), 
     as.integer(hergm_list$MCMCparams$interval),
-    as.integer(hergm_list$verbose), as.integer(hergm_list$MHproposal$arguments$constraints$bd$attribs),
-    as.integer(hergm_list$MHproposal$arguments$constraints$bd$maxout), as.integer(hergm_list$MHproposal$arguments$constraints$bd$maxin),
-    as.integer(hergm_list$MHproposal$arguments$constraints$bd$minout), as.integer(hergm_list$MHproposal$arguments$constraints$bd$minin),
-    as.integer(hergm_list$MHproposal$arguments$constraints$bd$condAllDegExact), as.integer(length(hergm_list$MHproposal$arguments$constraints$bd$attribs)),
+    as.integer(hergm_list$verbose),
+    as.integer(hergm_list$MHproposal$arguments$constraints$bd$attribs),
+    as.integer(hergm_list$MHproposal$arguments$constraints$bd$maxout), 
+    as.integer(hergm_list$MHproposal$arguments$constraints$bd$maxin),
+    as.integer(hergm_list$MHproposal$arguments$constraints$bd$minout), 
+    as.integer(hergm_list$MHproposal$arguments$constraints$bd$minin),
+    as.integer(hergm_list$MHproposal$arguments$constraints$bd$condAllDegExact), 
+    as.integer(length(hergm_list$MHproposal$arguments$constraints$bd$attribs)),
     as.integer(hergm_list$maxedges),
     as.integer(hergm_list$max_iteration),
     as.integer(hergm_list$between),
@@ -107,13 +116,18 @@ hergm.wrapper <- function(seed, hergm_list)
     as.double(hergm_list$eta_precision_shape),
     as.double(hergm_list$eta_precision_rate),
     as.integer(hergm_list$indicator),
-    as.integer(hergm_list$Clist$heads), as.integer(hergm_list$Clist$tails),
-    as.integer(hergm_list$Clist$nedges), as.integer(hergm_list$MCMCparams$MCMC.init.maxedges), as.integer(hergm_list$Clist$n),
-    as.integer(hergm_list$Clist$dir), as.integer(hergm_list$Clist$bipartite),
+    as.integer(hergm_list$Clist$heads), 
+    as.integer(hergm_list$Clist$tails),
+    as.integer(hergm_list$Clist$nedges), 
+    as.integer(hergm_list$MCMCparams$MCMC.init.maxedges), 
+    as.integer(hergm_list$Clist$n),
+    as.integer(hergm_list$Clist$dir), 
+    as.integer(hergm_list$Clist$bipartite),
     as.integer(hergm_list$Clist$nterms), 
     as.character(hergm_list$Clist$fnamestring), 
     as.character(hergm_list$Clist$snamestring),
-    as.character(hergm_list$MHproposal$name), as.character(hergm_list$MHproposal$pkgname),
+    as.character(hergm_list$MHproposal$name), 
+    as.character(hergm_list$MHproposal$pkgname),
     as.double(hergm_list$Clist$inputs),
     as.double(hergm_list$Clist$inputs),
     as.double(hergm_list$theta),
@@ -123,10 +137,14 @@ hergm.wrapper <- function(seed, hergm_list)
     as.integer(hergm_list$MCMCparams$interval),
     newnwheads = integer(hergm_list$maxedges),
     newnwtails = integer(hergm_list$maxedges),
-    as.integer(hergm_list$verbose), as.integer(hergm_list$MHproposal$arguments$constraints$bd$attribs),
-    as.integer(hergm_list$MHproposal$arguments$constraints$bd$maxout), as.integer(hergm_list$MHproposal$arguments$constraints$bd$maxin),
-    as.integer(hergm_list$MHproposal$arguments$constraints$bd$minout), as.integer(hergm_list$MHproposal$arguments$constraints$bd$minin),
-    as.integer(hergm_list$MHproposal$arguments$constraints$bd$condAllDegExact), as.integer(length(hergm_list$MHproposal$arguments$constraints$bd$attribs)),
+    as.integer(hergm_list$verbose), 
+    as.integer(hergm_list$MHproposal$arguments$constraints$bd$attribs),
+    as.integer(hergm_list$MHproposal$arguments$constraints$bd$maxout), 
+    as.integer(hergm_list$MHproposal$arguments$constraints$bd$maxin),
+    as.integer(hergm_list$MHproposal$arguments$constraints$bd$minout), 
+    as.integer(hergm_list$MHproposal$arguments$constraints$bd$minin),
+    as.integer(hergm_list$MHproposal$arguments$constraints$bd$condAllDegExact), 
+    as.integer(length(hergm_list$MHproposal$arguments$constraints$bd$attribs)),
     as.integer(hergm_list$maxedges),
     as.integer(hergm_list$max_iteration),
     as.integer(hergm_list$between),
